autowisp.fit_expression.list_terms_visitor module — AutoWISP documentation

# autowisp.fit_expression.list_terms_visitor module

## Class Inheritance Diagram

Implement a visitor to parsed fit terms expressions that prints all terms.

class autowisp.fit_expression.list_terms_visitor.ListTermsVisitor(*args, **kwargs)

  Bases: `ProcessTermsVisitor`

  Visitor to parsed fit terms expressions listing all terms.

  _end_expansion()

    The final step of performing a term set expansion operation.

  _process_polynomial_term(input_terms, term_powers)

    Add a human readable, yet evaluatable string of the term.

  visitFit_term(ctx: Fit_termContext)

    Return a string representaiton of the corresponding term.

  visitFit_terms_expression(ctx: Fit_terms_expressionContext)

    Return all terms defined by the term expression.